@@ -34,4 +34,8 @@ from transformer import Transformer
 from xmlaggregator import XMLAggregator
 from xmlfilter import XMLFilter
 from xmlmatcher import XMLMatcher
-from flowcontroller import FlowController
\ No newline at end of file
+from flowcontroller import FlowController
+from mdpactors import MDPClient
+from mdpactors import MDPWorker
+from mdpbroker import MajorDomoBroker
+from mdpregistrar import BrokerRegistrationService
\ No newline at end of file
