@@ -3,7 +3,7 @@
 #
 #       stdout.py
 #
-#       Copyright 2013 Jelle Smet development@smetj.net
+#       Copyright 2014 Adam Fiebig fiebig.adam@gmail.com
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 from compysition import Actor
 from compysition.module.util import RotatingFileHandler, LoggingConfigLoader
 import gevent
-#from gevent import queue
 from compysition import Queue
 from os import getpid
 from time import strftime, localtime
@@ -57,7 +56,7 @@ class FileLogger(Actor):
 
         self.file_logger = logging.getLogger(self.name)
 
-        logHandler = RotatingFileHandler(r'{0}'.format(self.filepath), maxBytes=self.config.config['maxBytes'], backupCount=self.config.config['backupCount'])
+        logHandler = RotatingFileHandler(r'{0}'.format(self.filepath), maxBytes=int(self.config.config['maxBytes']), backupCount=int(self.config.config['backupCount']))
         logFormatter = logging.Formatter('%(message)s') # We will do ALL formatting ourselves in qlogger, as we want to be extremely literal to make sure the timestamp
                                                         # is generated at the time that logger.log was invoked, not the time it was written to file
         logHandler.setFormatter(logFormatter)
